#!/bin/sh
#
# subversion install
#
prog_dir=`dirname \`realpath $0\``
# source the service.sh script to get any variables
. ${prog_dir}/service.sh status > /dev/null

SHARES_DIR="/mnt/DroboFS/Shares"
logfile=${prog_dir}/install.log

echo "installing $name $version at `date`" > ${logfile}
echo "" >> ${logfile}

# _install
# args: none
# returns 0 on success, non 0 on error
_install()
{
  # first make sure service config exists or create it
  svc_conf="$prog_dir/.service.conf"
  #echo "svc_conf:  ${svc_conf}"
  if ! _check_svc_conf ${svc_conf}; then
    echo "failed to create ${svc_conf}" >> ${logfile}
    # not a fatal error, will use default directory
  fi
  
} # _install


# _check_svc_conf
# args: 
# - name of the service config file
# returns: 0 if service config exists or is created
_check_svc_conf()
{
  config=$1
  if [ -e "${config}" ]; then
    echo "keeping existing service config: ${config}" >> ${logfile}
    return 0
  fi  

  found_repos="";
  # search for a share starting with SVN or Subversion, and use it
  echo "searching for a svn* or subversion* shared repo folder..." >> ${logfile}
  for x in ${SHARES_DIR}/[Ss][Vv][Nn]* ${SHARES_DIR}/[Ss]ubversion*
  do
    echo "checking: $x" >> ${logfile}
    if [ -d "${x}" ]; then
      found_repos="${x}";
      echo "setting repo root folder to: ${found_repos}" >> ${logfile}
      break;
    fi
  done

  if [ -z "${found_repos}" ]; then
    echo "no Subversion shares were found, using default ./repos" >> ${logfile} 
  fi  

  # create the service config file
cat << END_OF_SC > ${config}
# ${config}
# 
# The service config file for this drobo app 
# should only be called from the service.sh!
#
# change this setting to define the subversion repository root
repos_root="${found_repos}"
END_OF_SC
  echo "created service config: ${config}" >> ${logfile}
  echo "edit .service.conf to change the repos_root path." >> ${logfile}
  echo "" >> ${logfile}
  return 0
} # _check_svc_conf

# execute the actual install 
if _install; then
  echo "" >> ${logfile}
  echo "install completed successfully!" >> ${logfile}
  return 0
else
  echo "" >> ${logfile}
  echo "installation was NOT completed!" >> ${logfile}
  return 1
fi

